!-------------------------------------------------------------------------------

!                      Code_Saturne version 4.0-alpha
!                      --------------------------
! This file is part of Code_Saturne, a general-purpose CFD tool.
!
! Copyright (C) 1998-2019 EDF S.A.
!
! This program is free software; you can redistribute it and/or modify it under
! the terms of the GNU General Public License as published by the Free Software
! Foundation; either version 2 of the License, or (at your option) any later
! version.
!
! This program is distributed in the hope that it will be useful, but WITHOUT
! ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
! FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
! details.
!
! You should have received a copy of the GNU General Public License along with
! this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
! Street, Fifth Floor, Boston, MA 02110-1301, USA.

!-------------------------------------------------------------------------------

!===============================================================================
! Purpose:
! -------

!> \file cs_user_mass_source_terms.f90
!>
!> \brief Mass source term example.
!>
!> See \subpage cs_user_mass_source_terms for examples.
!>

!-------------------------------------------------------------------------------
!>           Arguments
!______________________________________________________________________________.
!  mode           name          role
!______________________________________________________________________________!
!> \param[in]     nvar          total number of variables
!> \param[in]     nscal         total number of scalars
!> \param[in]     ncepdp        number of cells with head loss terms
!> \param[in]     ncesmp        number of cells with mass source terms
!> \param[in]     iappel        indicates which at which stage the routine is
!>                              is called
!> \param[in]     icepdc        index number of cells with head loss terms
!>                              (usable only for iappel > 1)
!> \param[in,out] icetsm        index number of cells with mass source terms
!> \param[in,out] itypsm        type of mass source term for each variable
!>                               (see uttsma.f90)
!> \param[in]     izctsm        cells zone for mass source terms definition
!> \param[in]     dt            time step (per cell)
!> \param[in]     ckupdc        head loss coefficient
!> \param[in,out] smacel        value associated to each variable in the mass
!>                              source terms or mass rate
!______________________________________________________________________________!

subroutine cs_user_mass_source_terms &
 ( nvar   , nscal  , ncepdp ,                                     &
   ncesmp , iappel ,                                              &
   icepdc , icetsm , itypsm , izctsm ,                            &
   dt     ,                                                       &
   ckupdc , smacel )

!===============================================================================
! Module files
!===============================================================================

use paramx
use numvar
use entsor
use optcal
use cstphy
use cstnum
use parall
use period
use mesh
use cs_c_bindings

!===============================================================================

implicit none

! Arguments

integer          nvar   , nscal
integer          ncepdp , ncesmp
integer          iappel

integer          icepdc(*)
integer          icetsm(ncesmp), itypsm(ncesmp,nvar)
integer          izctsm(ncel)

double precision dt(ncelet)
double precision ckupdc(6,ncepdp)
double precision smacel(ncesmp,nvar)

!< [loc_var]
! Local variables

integer          ieltsm
integer          ifac, ii
integer          ilelt, nlelt
integer          izone, ivar

double precision wind, wind2
double precision dh, ustar2
double precision xkent, xeent
double precision flucel
double precision vtot  , gamma
character*80     chaine

integer, allocatable, dimension(:) :: lstelt
double precision, dimension(:), pointer :: cvar_sca1
type(var_cal_opt) :: vcopt

!< [loc_var]

!===============================================================================

!< [allocate]
! Allocate a temporary array for cells selection
allocate(lstelt(ncel))
!< [allocate]

!< [one_or_two]
if (iappel.eq.1.or.iappel.eq.2) then
!< [one_or_two]

!===============================================================================
! 1. One or two calls

!   First call:
!
!       iappel = 1: ncesmp: calculation of the number of cells with
!                             mass source term


!   Second call (if ncesmp>0):
!       iappel = 2: icetsm: index number of cells with mass source terms

! WARNINGS
! ========
!   Do not use smacel in this section (it is set on the third call, iappel=3)

!   Do not use icetsm in this section on the first call (iappel=1)

!   This section (iappel=1 or 2) is only accessed at the beginning of a
!     calculation. Should the localization of the mass source terms evolve
!     in time, the user must identify at the beginning all cells that can
!     potentially become a mass source term.

!===============================================================================


!  1.1 To be completed by the user: cell selection
!  -----------------------------------------------

! Example 1: No mass source term (default)


! Example 2 : Mass source term one in the cells that
!              have a boundary face of color 3 and the cells
!              with a coordinate X between 2.5 and 5.
!
!     In this test in two parts, one mut pay attention not to count
!      the cells twice (a cell with a boundary face of color 3 can
!      also have a coordinate X between 2.5 and 5).
!     One should also pay attention that, on the first call, the
!      array icetsm doesn't exist yet. It mustn't be used outside
!      of tests (iappel.eq.2).

!< [example_1_2]
  izone = 0
  ieltsm = 0

  ! Cells with coordinate X between 2.5 and 5.

  call getcel('X >= 55.0 and X <= 65.0 and Z <=1.',nlelt,lstelt)

  izone = izone + 1

  do ilelt = 1, nlelt
    ii = lstelt(ilelt)
    izctsm(ii) = izone
    ieltsm = ieltsm + 1
    if (iappel.eq.2) icetsm(ieltsm) = ii
  enddo


!  1.2 Generic subsection: do not modify
!  -------------------------------------

! --- For iappel = 1,
!      Specification of ncesmp. This block is valid for both examples.
!< [generic_sub]
  if (iappel.eq.1) then
    ncesmp = ieltsm
  endif
!< [generic_sub]
!-------------------------------------------------------------------------------

!< [call_3]
elseif (iappel.eq.3) then
!< [call_3]

!===============================================================================

! 2. For ncesmp > 0 , third call

!       iappel = 3 : itypsm : type of mass source term
!                    smacel : mass source term


! Remark
! ======
! If itypsm(ieltsm,ivar) is set to 1, smacel(ieltsm,ivar) must be set.

!===============================================================================

!  2.1 To be completed by the user: itypsm and smacel
!  --------------------------------------------------
!-------------------------------------------------------------------------------

! Example 2 : simulation of a suction (by a pump for instance) with a
!             total rate of 80 000 kg/s.
!             The suction rate is supposed to be uniformly distributed
!             on all the cells selected above.

  ! Calculation of the total volume of the area where the mass source
  !   term is imposed (the case of parallel computing is taken into
  !   account with the call to parsom).

!< [calcul_total]
  vtot = 0.d0
  do ieltsm = 1, ncesmp
    vtot = vtot + volume(icetsm(ieltsm))
  enddo
  if (irangp.ge.0) then
    call parsom (vtot)
  endif
!< [calcul_total]

  ! The mass suction rate is gamma = -80000/vtot (in kg/m3/s)
  ! It is set below, with a test for cases where vtot=0. The total
  ! mass rate is calculated for verification.

!< [mass_suction]
  if (vtot.gt.0.d0) then
    gamma = 0.000000232873d0/vtot
  else
    write(nfecra,9000) vtot
    call csexit (1)
  endif

  flucel = 0.d0
  do ieltsm = 1, ncesmp
    smacel(ieltsm,ipr) = gamma
    if (nscal.gt.0) then
      do ii = 1, nscal
          ivar = isca(ii)
          call field_get_val_s(ivarfl(ivar), cvar_sca1)
          itypsm(ieltsm,isca(ii)) = 1
          smacel(ieltsm,isca(ii)) = 1.d0
      enddo
    endif
    flucel = flucel+                                          &
         volume(icetsm(ieltsm))*smacel(ieltsm,ipr)
  enddo

  if (irangp.ge.0) then
    call parsom (flucel)
  endif

!-------------------------------------------------------------------------------
!< [end_call_3]
endif
!< [end_call_3]
!--------
! Formats
!--------
!< [format]
 1000 format(/,'Mass rate generated in the domain: ',E14.5,/)

 2000 format(/,'Mass flux rate generated in the domain: ',E14.5,/,         &
               '                         distributed on the volume: ',E14.5)

 9000 format(/,'Error in cs_user_mass_source_terms',/,                     &
               '   the volume of the mass suction area is = ',E14.5,/)
!< [format]
!----
! End
!----
!< [deallocate]
! Deallocate the temporary array
deallocate(lstelt)

return
end subroutine cs_user_mass_source_terms
!< [deallocate]
