/*============================================================================
 * Define postprocessing output.
 *============================================================================*/

/* Code_Saturne version 6.0.0 */

/*
  This file is part of Code_Saturne, a general-purpose CFD tool.

  Copyright (C) 1998-2019 EDF S.A.

  This program is free software; you can redistribute it and/or modify it under
  the terms of the GNU General Public License as published by the Free Software
  Foundation; either version 2 of the License, or (at your option) any later
  version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  details.

  You should have received a copy of the GNU General Public License along with
  this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
  Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/

/*----------------------------------------------------------------------------*/

#include "cs_defs.h"

/*----------------------------------------------------------------------------
 * Standard C library headers
 *----------------------------------------------------------------------------*/

#include "stdlib.h"
#include "string.h"

/*----------------------------------------------------------------------------
 *  Local headers
 *----------------------------------------------------------------------------*/

#include "bft_mem.h"
#include "bft_error.h"

#include "cs_base.h"
#include "cs_field.h"
#include "cs_geom.h"
#include "cs_interpolate.h"
#include "cs_mesh.h"
#include "cs_selector.h"
#include "cs_parall.h"
#include "cs_post.h"
#include "cs_post_util.h"
#include "cs_probe.h"
#include "cs_time_plot.h"

#include "cs_field_pointer.h"
#include "cs_parameters.h"
#include "cs_physical_constants.h"
#include "cs_turbulence_model.h"

/*----------------------------------------------------------------------------
 *  Header for the current file
 *----------------------------------------------------------------------------*/

#include "cs_prototypes.h"

/*----------------------------------------------------------------------------*/

BEGIN_C_DECLS

/*============================================================================
 * Local (user defined) function definitions
 *============================================================================*/
/*----------------------------------------------------------------------------*/
/*!
 * \brief Define monitoring probes and profiles.
 *
 * Profiles are defined as sets of probes.
 */
/*----------------------------------------------------------------------------*/

void
cs_user_postprocess_probes(void)
{
  /* Define monitoring probes */

  /* A writer (id = CS_POST_WRITER_PROBES) using the format "time_plot" is
     associated by default to a set of monitoring probes.
     This is not the case for a profile. */

  /*! [post_define_probes_1] */
  {
    cs_probe_set_t  *pset = cs_probe_set_create("Monitoring");

    cs_probe_set_add_probe(pset, 60, 60, 1, "M1");
    cs_probe_set_add_probe(pset, 60, 60, 2, "M2");
    cs_probe_set_add_probe(pset, 60, 60, 5, "M3");
    cs_probe_set_add_probe(pset, 60, 60, 10, "M4");
    cs_probe_set_add_probe(pset, 60, 60, 15, "M5");
    cs_probe_set_add_probe(pset, 60, 60, 20, "M6");
    cs_probe_set_add_probe(pset, 60, 60, 25, "M7");
    cs_probe_set_add_probe(pset, 60, 60, 30, "M8");
    cs_probe_set_add_probe(pset, 60, 60, 50, "M9");
    cs_probe_set_add_probe(pset, 60, 60, 70, "M10");
    cs_probe_set_add_probe(pset, 60, 60, 90, "M11");
    cs_probe_set_add_probe(pset, 60, 120, 1, "M12");
    cs_probe_set_add_probe(pset, 60, 120, 2, "M13");
    cs_probe_set_add_probe(pset, 60, 120, 5, "M14");
    cs_probe_set_add_probe(pset, 60, 120, 10, "M15");
    cs_probe_set_add_probe(pset, 60, 120, 15, "M16");
    cs_probe_set_add_probe(pset, 60, 120, 20, "M17");
    cs_probe_set_add_probe(pset, 60, 120, 25, "M18");
    cs_probe_set_add_probe(pset, 60, 120, 30, "M19");
    cs_probe_set_add_probe(pset, 60, 120, 50, "M20");
    cs_probe_set_add_probe(pset, 60, 120, 70, "M21");
    cs_probe_set_add_probe(pset, 60, 120, 90, "M22");
    cs_probe_set_add_probe(pset, 60, 180, 1, "M23");
    cs_probe_set_add_probe(pset, 60, 180, 2, "M24");
    cs_probe_set_add_probe(pset, 60, 180, 5, "M25");
    cs_probe_set_add_probe(pset, 60, 180, 10, "M26");
    cs_probe_set_add_probe(pset, 60, 180, 15, "M27");
    cs_probe_set_add_probe(pset, 60, 180, 20, "M28");
    cs_probe_set_add_probe(pset, 60, 180, 25, "M29");
    cs_probe_set_add_probe(pset, 60, 180, 30, "M30");
    cs_probe_set_add_probe(pset, 60, 180, 50, "M31");
    cs_probe_set_add_probe(pset, 60, 180, 70, "M32");
    cs_probe_set_add_probe(pset, 60, 180, 90, "M33");
    cs_probe_set_add_probe(pset, 25, 60, 1, "N1");
    cs_probe_set_add_probe(pset, 25, 60, 2, "N2");
    cs_probe_set_add_probe(pset, 25, 60, 5, "N3");
    cs_probe_set_add_probe(pset, 25, 60, 10, "N4");
    cs_probe_set_add_probe(pset, 25, 60, 15, "N5");
    cs_probe_set_add_probe(pset, 25, 60, 20, "N6");
    cs_probe_set_add_probe(pset, 25, 60, 25, "N7");
    cs_probe_set_add_probe(pset, 25, 60, 30, "N8");
    cs_probe_set_add_probe(pset, 25, 60, 50, "N9");
    cs_probe_set_add_probe(pset, 25, 60, 70, "N10");
    cs_probe_set_add_probe(pset, 25, 60, 90, "N11");
    cs_probe_set_add_probe(pset, 25, 120, 1, "N12");
    cs_probe_set_add_probe(pset, 25, 120, 2, "N13");
    cs_probe_set_add_probe(pset, 25, 120, 5, "N14");
    cs_probe_set_add_probe(pset, 25, 120, 10, "N15");
    cs_probe_set_add_probe(pset, 25, 120, 15, "N16");
    cs_probe_set_add_probe(pset, 25, 120, 20, "N17");
    cs_probe_set_add_probe(pset, 25, 120, 25, "N18");
    cs_probe_set_add_probe(pset, 25, 120, 30, "N19");
    cs_probe_set_add_probe(pset, 25, 120, 50, "N20");
    cs_probe_set_add_probe(pset, 25, 120, 70, "N21");
    cs_probe_set_add_probe(pset, 25, 120, 90, "N22");
    cs_probe_set_add_probe(pset, 25, 180, 1, "N23");
    cs_probe_set_add_probe(pset, 25, 180, 2, "N24");
    cs_probe_set_add_probe(pset, 25, 180, 5, "N25");
    cs_probe_set_add_probe(pset, 25, 180, 10, "N26");
    cs_probe_set_add_probe(pset, 25, 180, 15, "N27");
    cs_probe_set_add_probe(pset, 25, 180, 20, "N28");
    cs_probe_set_add_probe(pset, 25, 180, 25, "N29");
    cs_probe_set_add_probe(pset, 25, 180, 30, "N30");
    cs_probe_set_add_probe(pset, 25, 180, 50, "N31");
    cs_probe_set_add_probe(pset, 25, 180, 70, "N32");
    cs_probe_set_add_probe(pset, 25, 180, 90, "N33");

    cs_probe_set_add_probe(pset, 95, 60, 1, "O1");
    cs_probe_set_add_probe(pset, 95, 60, 2, "O2");
    cs_probe_set_add_probe(pset, 95, 60, 5, "O3");
    cs_probe_set_add_probe(pset, 95, 60, 10, "O4");
    cs_probe_set_add_probe(pset, 95, 60, 15, "O5");
    cs_probe_set_add_probe(pset, 95, 60, 20, "O6");
    cs_probe_set_add_probe(pset, 95, 60, 25, "O7");
    cs_probe_set_add_probe(pset, 95, 60, 30, "O8");
    cs_probe_set_add_probe(pset, 95, 60, 50, "O9");
    cs_probe_set_add_probe(pset, 95, 60, 70, "O10");
    cs_probe_set_add_probe(pset, 95, 60, 90, "O11");
    cs_probe_set_add_probe(pset, 95, 120, 1, "O12");
    cs_probe_set_add_probe(pset, 95, 120, 2, "O13");
    cs_probe_set_add_probe(pset, 95, 120, 5, "O14");
    cs_probe_set_add_probe(pset, 95, 120, 10, "O15");
    cs_probe_set_add_probe(pset, 95, 120, 15, "O16");
    cs_probe_set_add_probe(pset, 95, 120, 20, "O17");
    cs_probe_set_add_probe(pset, 95, 120, 25, "O18");
    cs_probe_set_add_probe(pset, 95, 120, 30, "O19");
    cs_probe_set_add_probe(pset, 95, 120, 50, "O20");
    cs_probe_set_add_probe(pset, 95, 120, 70, "O21");
    cs_probe_set_add_probe(pset, 95, 120, 90, "O22");
    cs_probe_set_add_probe(pset, 95, 180, 1, "O23");
    cs_probe_set_add_probe(pset, 95, 180, 2, "O24");
    cs_probe_set_add_probe(pset, 95, 180, 5, "O25");
    cs_probe_set_add_probe(pset, 95, 180, 10, "O26");
    cs_probe_set_add_probe(pset, 95, 180, 15, "O27");
    cs_probe_set_add_probe(pset, 95, 180, 20, "O28");
    cs_probe_set_add_probe(pset, 95, 180, 25, "O29");
    cs_probe_set_add_probe(pset, 95, 180, 30, "O30");
    cs_probe_set_add_probe(pset, 95, 180, 50, "O31");
    cs_probe_set_add_probe(pset, 95, 180, 70, "O32");
    cs_probe_set_add_probe(pset, 95, 180, 90, "O33");


  }



}

/*----------------------------------------------------------------------------*/
/*!
 * \brief User function for output of values on a post-processing mesh.
 *
 * \param[in]       mesh_name    name of the output mesh for the current call
 * \param[in]       mesh_id      id of the output mesh for the current call
 * \param[in]       cat_id       category id of the output mesh for the
 *                               current call
 * \param[in]       probes       pointer to associated probe set structure if
 *                               the mesh is a probe set, NULL otherwise
 * \param[in]       n_cells      local number of cells of post_mesh
 * \param[in]       n_i_faces    local number of interior faces of post_mesh
 * \param[in]       n_b_faces    local number of boundary faces of post_mesh
 * \param[in]       n_vertices   local number of vertices faces of post_mesh
 * \param[in]       cell_list    list of cells (0 to n-1) of post-processing
 *                               mesh
 * \param[in]       i_face_list  list of interior faces (0 to n-1) of
 *                               post-processing mesh
 * \param[in]       b_face_list  list of boundary faces (0 to n-1) of
 *                               post-processing mesh
 * \param[in]       vertex_list  list of vertices (0 to n-1) of
 *                               post-processing mesh
 * \param[in]       ts           time step status structure, or NULL
 */
/*----------------------------------------------------------------------------*/


/*----------------------------------------------------------------------------*/

END_C_DECLS
